chatter.migrations.0003_auto_20200922_1221 — django-chats 0.1.1 documentation

# Source code for chatter.migrations.0003_auto_20200922_1221

    # Generated by Django 3.1 on 2020-09-22 10:21

    from django.db import migrations

    class Migration(migrations.Migration):

        dependencies = [
            ('chatter', '0002_auto_20200922_1209'),
        ]

        operations = [
            migrations.RenameField(
                model_name='message',
                old_name='body',
                new_name='content',
            ),
            migrations.RemoveField(
                model_name='message',
                name='title',
            ),
        ]